@@ -1,12 +1,13 @@
 ## ----setup, include=FALSE-----------------------------------------------------
-set.seed(123)
 library(INLA)
 set.seed(123)
+if (file.exists("myinit.R")) source("myinit.R")
 inla.setOption(num.threads="1:1")
 inla.setOption(smtp="taucs")
 library(knitr)
 library(rmarkdown)
 knitr::opts_chunk$set(echo=TRUE, cache=FALSE, message=FALSE, warning=FALSE)
+knitr::opts_chunk$set(fig.path="figures/rgeneric/")
 
 ## ----eval=FALSE---------------------------------------------------------------
 #  model = inla.rgeneric.define(rmodel, ...)
